@@ -1,19 +1,20 @@
 from requests import Session
 from logging import getLogger
-from . import BaseSimdakPaud, RkasPaud
+from . import BaseSimdakPaud, SimdakRkasPaud
 
 
 class SimdakPaud(BaseSimdakPaud):
     def __init__(self, email: str, password: str):
         self._logger = getLogger(self.__class__.__name__)
-        self._session = Session()
         self._email = email
         self._password = password
         self._login = self.login()
         self._modul = self.modul()
-        self.rkas = RkasPaud(self._session)
+        self.rkas = SimdakRkasPaud()
 
     def login(self) -> bool:
+        if self._login:
+            raise PermissionError("Anda sudah login.")
         params = {"r": "site/login"}
         res = self._session.get(self._base_url, params=params)
         if not res.status_code == 200:
@@ -44,3 +45,6 @@ class SimdakPaud(BaseSimdakPaud):
         ):
             return True
         return False
+
+    def __del__(self):
+        self.logout()
